.. image:: https://circleci.com/gh/OneID/oneID-connect-python.svg?style=svg
    :target: https://circleci.com/gh/OneID/oneID-connect-python

oneID Connect
=============
oneID-connect is a Python authentication framework for the Internet of Things (IoT),
servers and end-users. By sending messages with digital signatures, you can authenticate
the origin of the message and ensure the message hasn't been tampered with.
oneID-connect makes it simple for projects that need to securely send messages and verify
the authentication of messages.

For more information, please visit the docs.
`<http://oneid-connect.readthedocs.org/en/latest/>`_

